"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchHttpClient = void 0;
const utils_1 = require("./utils");
/**
 * Dictionary with the request id as key and an `AbortController` as value.
 */
const requestAbortControllers = {};
/**
 * The `fetchHttpClient()` function is a http client implementation using the `fetch` WebAPI.
 *
 * @param endpoint - The endpoint to make the request to.
 * @param options - The request options.
 *
 * @returns A `Promise` object.
 *
 * @public
 */
const fetchHttpClient = (endpoint, { id = endpoint, parameters, properties } = {}) => {
    var _a;
    const url = (0, utils_1.buildUrl)(endpoint, parameters);
    (_a = requestAbortControllers[id]) === null || _a === void 0 ? void 0 : _a.abort();
    requestAbortControllers[id] = new AbortController();
    return fetch(url, { ...properties, signal: requestAbortControllers[id].signal }).then(utils_1.toJson);
};
exports.fetchHttpClient = fetchHttpClient;
//# sourceMappingURL=fetch.http-client.js.map